/*
  Expt7_Stage4_Tx - Transmitting Sketch
  Pressure values using BMP180
  Temperature and humidity values from DHT11
*/
#include <VirtualWire.h>
#include <VWComm.h>
#include <SFE_BMP180.h>
#include <Wire.h>
#include <dht.h>
#define ALTITUDE 100.0 //Coventry altitude (metres)
double P; // storage for pressure readings
const int transmit_pin = 2; // Tx data to D2
const int transmit_en_pin = 3; // reset default
const int dht_dpin = 8; // DHT11 data pin to D8
int hum; // variable to hold humidity values
int x; // variable to hold other values
SFE_BMP180 pressure; // create an object for BMP values
dht DHT; // create an object to use with DHT library
VWComm vwc; // create an object to use with VWComm
void setup()
{
  vw_set_tx_pin(transmit_pin); // define Tx data pin
  vw_set_ptt_pin(transmit_en_pin); // reset default
  vw_setup(2000); // Bits per sec
  vwc.sendStr("Start"); // synchronise with Rx
  delay(200); // delay to allow Rx to synchronise
  if (pressure.begin())
    vwc.sendStr("BMP180 init success");
  else
  {
    vwc.sendStr("BMP180 init fail");
    while (1); // Pause forever.
  }
}
void loop()
{
  P = getPressure(); // get a new pressure reading:
  vwc.sendStr("Pr (mb):"); // send text
  delay(200);
  vwc.sendFloat(float(P), 2); // send pressure value
  delay(200);
  DHT.read11(dht_dpin); // read data values
  x = int(DHT.humidity); // get humidity component
  vwc.sendStr("Hum % ="); // send text
  delay(200); // allow Rx to receive and report
  vwc.sendInt(x); // send humidity value
  delay(200); // allow Rx to receive and report
  x = int(DHT.temperature); // get temperature component
  vwc.sendStr("T.Celsius ="); // send text
  delay(200); // allow Rx to receive and report
  vwc.sendInt(x); // send temperature value
  delay(2000); // pause for 2 seconds
}
double getPressure()
{
  char status;
  double T, P, p0;
  status = pressure.startTemperature();
  if (status != 0)
  {
    delay(status);
    status = pressure.getTemperature(T);
    if (status != 0)
    {
      status = pressure.startPressure(3);
      if (status != 0)
      {
        delay(status);
        status = pressure.getPressure(P, T);
        if (status != 0)
        {
          p0 = pressure.sealevel(P, ALTITUDE);
          return (p0);
        }
      }
    }
  }
}
